==> haskell-optparse-simple-0.1.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1
id: optparse-simple-0.1.1-AnA3zwCh0fk1XKqsBRLuvQ
key: optparse-simple-0.1.1-AnA3zwCh0fk1XKqsBRLuvQ
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 563ce5c8e25c42c5962bf862e99f9031
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/optparse-simple-0.1.1
hs-libraries: HSoptparse-simple-0.1.1-AnA3zwCh0fk1XKqsBRLuvQ
depends:
    base-4.12.0.0 githash-0.1.3.1-4Mvns9qDldY1VPZwvCfYJN
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U
    template-haskell-2.14.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.1.1
id: optparse-simple-0.1.1-VpNTOUlLltD8WQ0OsGIJs
key: optparse-simple-0.1.1-VpNTOUlLltD8WQ0OsGIJs
license: BSD-3-Clause
copyright: 2015-2017 FP Complete
maintainer: chrisdone@fpcomplete.com
author: FP Complete
homepage: https://github.com/fpco/optparse-simple#readme
synopsis: Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>
category: Options
abi: 5f23229c082e5f2ea0ce24ed02ca788e
exposed: True
exposed-modules:
    Options.Applicative.Simple
hidden-modules: Paths_optparse_simple
import-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/optparse-simple-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/optparse-simple-0.1.1
hs-libraries: HSoptparse-simple-0.1.1-VpNTOUlLltD8WQ0OsGIJs
depends:
    base-4.12.0.0 githash-0.1.3.1-ATeZH51kPsF8CkQDtPvSjs
    optparse-applicative-0.14.3.0-BVXhkxJuCJ17E9CBbUEb4U
    template-haskell-2.14.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
